@@ -1,5 +1,10 @@
+import logging
+
 from ._constants import AlbumSortOrder
 from ._version import __version__
+from .albuminfo import AlbumInfo, ImportInfo, ProjectInfo, FolderInfo
+from .debug import is_debug, set_debug
+from .exifinfo import ExifInfo
 from .exiftool import ExifTool
 from .export_db import ExportDB
 from .fileutil import FileUtil, FileUtilNoOp
@@ -14,15 +19,16 @@ from .placeinfo import PlaceInfo
 from .queryoptions import QueryOptions
 from .scoreinfo import ScoreInfo
 from .searchinfo import SearchInfo
-from .utils import _debug, _get_logger, _set_debug
+from .utils import _get_logger
+
+if not is_debug():
+    logging.disable(logging.DEBUG)
 
 __all__ = [
-    "__version__",
-    "_debug",
-    "_get_logger",
-    "_set_debug",
+    "AlbumInfo",
     "AlbumSortOrder",
     "CommentInfo",
+    "ExifInfo",
     "ExifTool",
     "ExportDB",
     "ExportDBTemp",
@@ -30,15 +36,22 @@ __all__ = [
     "ExportResults",
     "FileUtil",
     "FileUtilNoOp",
+    "ImportInfo",
     "LikeInfo",
     "MomentInfo",
     "PersonInfo",
     "PhotoExporter",
     "PhotoInfo",
-    "PhotosDB",
     "PhotoTemplate",
+    "PhotosDB",
     "PlaceInfo",
+    "ProjectInfo",
     "QueryOptions",
     "ScoreInfo",
     "SearchInfo",
+    "__version__",
+    "_get_logger",
+    "is_debug",
+    "set_debug",
+    "FolderInfo",
 ]
