@@ -6,8 +6,10 @@ import gzip
 import json
 import logging
 import os
+import os.path
 import pathlib
 import pickle
+import re
 import sqlite3
 import sys
 import time
@@ -15,7 +17,7 @@ from contextlib import suppress
 from io import StringIO
 from sqlite3 import Error
 from tempfile import TemporaryDirectory
-from typing import Any, Optional, Tuple, Union, List
+from typing import Any, List, Optional, Tuple, Union
 
 from tenacity import retry, stop_after_attempt
 
@@ -30,7 +32,7 @@ __all__ = [
     "ExportDBTemp",
 ]
 
-OSXPHOTOS_EXPORTDB_VERSION = "7.0"
+OSXPHOTOS_EXPORTDB_VERSION = "7.1"
 OSXPHOTOS_ABOUT_STRING = f"Created by osxphotos version {__version__} (https://github.com/RhetTbull/osxphotos) on {datetime.datetime.now()}"
 
 # max retry attempts for methods which use tenacity.retry
@@ -209,6 +211,35 @@ class ExportDB:
         except Error as e:
             logging.warning(e)
 
+    def get_target_for_file(
+        self, uuid: str, filename: Union[str, pathlib.Path]
+    ) -> Optional[str]:
+        """query database for file matching file name and return the matching filename if there is one;
+           otherwise return None; looks for file.ext, file (1).ext, file (2).ext and so on to find the
+           actual target name that was used to export filename
+
+        Returns: the matching filename or None if no match found
+        """
+        conn = self._conn
+        c = conn.cursor()
+        filepath_normalized = self._normalize_filepath_relative(filename)
+        filepath_stem = os.path.splitext(filepath_normalized)[0]
+        c.execute(
+            "SELECT uuid, filepath, filepath_normalized FROM export_data WHERE uuid = ? AND filepath_normalized LIKE ?",
+            (
+                uuid,
+                f"{filepath_stem}%",
+            ),
+        )
+        results = c.fetchall()
+
+        for result in results:
+            filepath_normalized = os.path.splitext(result[2])[0]
+            if re.match(re.escape(filepath_stem) + r"(\s\(\d+\))?$", filepath_normalized):
+                return os.path.join(self.export_dir, result[1])
+
+        return None
+
     def get_previous_uuids(self):
         """returns list of UUIDs of previously exported photos found in export database"""
         conn = self._conn
@@ -481,6 +512,10 @@ class ExportDB:
             # create report_data table
             self._migrate_6_0_to_7_0(conn)
 
+        if version[1] < "7.1":
+            # add timestamp to export_data
+            self._migrate_7_0_to_7_1(conn)
+
         conn.execute("VACUUM;")
         conn.commit()
 
@@ -698,6 +733,32 @@ class ExportDB:
         except Error as e:
             logging.warning(e)
 
+    def _migrate_7_0_to_7_1(self, conn):
+        try:
+            c = conn.cursor()
+            c.execute("""ALTER TABLE export_data ADD COLUMN timestamp DATETIME;""")
+            c.execute(
+                """
+                CREATE TRIGGER insert_timestamp_trigger
+                AFTER INSERT ON export_data
+                BEGIN
+                   UPDATE export_data SET timestamp = STRFTIME('%Y-%m-%d %H:%M:%f', 'NOW') WHERE id = NEW.id;
+                END;
+                """
+            )
+            c.execute(
+                """
+                CREATE TRIGGER update_timestamp_trigger
+                AFTER UPDATE On export_data
+                BEGIN
+                    UPDATE export_data SET timestamp = STRFTIME('%Y-%m-%d %H:%M:%f', 'NOW') WHERE id = NEW.id;
+                END;
+                """
+            )
+            conn.commit()
+        except Error as e:
+            logging.warning(e)
+
     def _perform_db_maintenace(self, conn):
         """Perform database maintenance"""
         try:
@@ -1059,6 +1120,21 @@ class ExportRecord:
         if not self._context_manager:
             conn.commit()
 
+    @property
+    def timestamp(self):
+        """returns the timestamp value"""
+        conn = self._conn
+        c = conn.cursor()
+        if row := c.execute(
+            "SELECT timestamp FROM export_data WHERE filepath_normalized = ?;",
+            (self._filepath_normalized,),
+        ).fetchone():
+            return row[0]
+
+        raise ValueError(
+            f"No timestamp found in database for {self._filepath_normalized}"
+        )
+
     def asdict(self):
         """Return dict of self"""
         exifdata = json.loads(self.exifdata) if self.exifdata else None
@@ -1067,6 +1143,7 @@ class ExportRecord:
             "filepath": self.filepath,
             "filepath_normalized": self.filepath_normalized,
             "uuid": self.uuid,
+            "timestamp": self.timestamp,
             "digest": self.digest,
             "src_sig": self.src_sig,
             "dest_sig": self.dest_sig,
