@@ -1,6 +1,7 @@
 """ utility functions used by PhotosDB """
 
 import logging
+import pathlib
 import plistlib
 
 from .._constants import (
@@ -15,9 +16,17 @@ from .._constants import (
 )
 from ..utils import _open_sql_file
 
+__all__ = [
+    "get_db_version",
+    "get_model_version",
+    "get_db_model_version",
+    "UnknownLibraryVersion",
+    "get_photos_library_version",
+]
+
 
 def get_db_version(db_file):
-    """ Gets the Photos DB version from LiGlobals table
+    """Gets the Photos DB version from LiGlobals table
 
     Args:
         db_file: path to photos.db database file containing LiGlobals table
@@ -44,11 +53,11 @@ def get_db_version(db_file):
 
 
 def get_model_version(db_file):
-    """ Returns the database model version from Z_METADATA
-    
+    """Returns the database model version from Z_METADATA
+
     Args:
         db_file: path to Photos.sqlite database file containing Z_METADATA table
-        
+
     Returns: model version as str
     """
 
@@ -67,11 +76,11 @@ def get_model_version(db_file):
 
 
 def get_db_model_version(db_file):
-    """ Returns Photos version based on model version found in db_file
-    
+    """Returns Photos version based on model version found in db_file
+
     Args:
         db_file: path to Photos.sqlite file
-    
+
     Returns: int of major Photos version number (e.g. 5 or 6).
     If unknown model version found, logs warning and returns most current Photos version.
     """
@@ -94,7 +103,7 @@ class UnknownLibraryVersion(Exception):
 
 
 def get_photos_library_version(library_path):
-    """Return int indicating which Photos version a library was created with """
+    """Return int indicating which Photos version a library was created with"""
     library_path = pathlib.Path(library_path)
     db_ver = get_db_version(str(library_path / "database" / "photos.db"))
     db_ver = int(db_ver)
@@ -104,9 +113,8 @@ def get_photos_library_version(library_path):
         return 3
     if db_ver == int(_PHOTOS_4_VERSION):
         return 4
-    if db_ver != int(_PHOTOS_5_VERSION):
-        raise UnknownLibraryVersion(f"db_ver = {db_ver}")
 
+    # assume it's a Photos 5+ library, get the model version to determine which version
     model_ver = get_model_version(str(library_path / "database" / "Photos.sqlite"))
     model_ver = int(model_ver)
     if _PHOTOS_5_MODEL_VERSION[0] <= model_ver <= _PHOTOS_5_MODEL_VERSION[1]:
